@@ -3,7 +3,10 @@
 ## Generic SecurePass Class to access APIs of Dreamliner
 ## www.secure-pass.net
 ##
+## This code is released under GPLv2
+##
 ## Contains some code from Ganeti project (c) Google Inc.
+## Copyright (C) 2010, 2011, 2012 Google Inc
 ##
 ## This library is under development, please sync from:
 ## https://github.com/gpaterno/securepass-tools
@@ -139,13 +142,44 @@ class SecurePass(object):
 
         request = {}
         request['MESSAGE'] = message
-        response = self._SendRequest(HTTP_POST, "/api/v1/log", content=request)
+        response = self._SendRequest(HTTP_POST, "/api/v1/logs/log", content=request)
 
         if response['rc'] == 0:
             print "Log sent"
         else:
             print response['errorMsg']
 
+
+    def get_logs(self, realm=None, start=None, end=None):
+        """ Get the list of logs
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        ## Start date
+        if start is not None:
+            request['START'] = start
+
+        ## End date
+        if end is not None:
+            request['END'] = end
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/logs/get", content=request)
+
+        if response['rc'] == 0:
+
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
+
+
     ##
     ## SecurePass Application handling
     ##
@@ -195,7 +229,7 @@ class SecurePass(object):
 
     # Create application
     def app_add(self, label="", allow_network_ipv4=None, allow_network_ipv6=None,
-                write=False, group=None, realm=None):
+                write=False, privacy=False, group=None, realm=None):
         """ Add an application to SecurePass
         """
 
@@ -203,6 +237,7 @@ class SecurePass(object):
 
         request['LABEL'] = label
         request['WRITE'] = write
+        request['PRIVACY'] = privacy
 
         if allow_network_ipv4 is not None:
             request['ALLOW_NETWORK_IPv4'] = allow_network_ipv4
@@ -255,7 +290,7 @@ class SecurePass(object):
     ## Modify the application
     # Create application
     def app_modify(self, app_id=None, label=None, allow_network_ipv4=None, allow_network_ipv6=None,
-                write=None, group=None, realm=None):
+                write=None, privacy=None, group=None, realm=None):
         """ Modify an application in SecurePass
         """
 
@@ -270,6 +305,9 @@ class SecurePass(object):
         if write is not None:
             request['WRITE'] = write
 
+        if privacy is not None:
+            request['PRIVACY'] = privacy
+
         if allow_network_ipv4 is not None:
             request['ALLOW_NETWORK_IPv4'] = allow_network_ipv4
 
@@ -771,3 +809,79 @@ class SecurePass(object):
 
         else:
             raise Exception(response['errorMsg'])
+
+
+    ##
+    ## SecurePass Realm handling xattrs/global policies
+    ##
+
+    def realm_xattr_list(self, realm=None):
+        """ Get Realm' extended attributes
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/realms/xattrs/list", content=request)
+
+        if response['rc'] == 0:
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
+
+
+    def realm_xattr_set(self, realm=None, attribute=None, value=None):
+        """ Set Realm' extended attributes
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        if attribute is not None:
+            request['ATTRIBUTE'] = attribute
+
+        if value is not None:
+            request['VALUE'] = value
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/realms/xattrs/set", content=request)
+
+        if response['rc'] == 0:
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
+
+
+    def realm_xattr_delete(self, realm=None, attribute=None):
+        """ Delete  Realm' extended attribute
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        if attribute is not None:
+            request['ATTRIBUTE'] = attribute
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/realms/xattrs/delete", content=request)
+
+        if response['rc'] == 0:
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
\ No newline at end of file
